CustomersResource class

Provides CRUD operations for Openpay customers.

Constructors

CustomersResource(OpenpayHttpClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(OpenpayCustomer customer) Future<OpenpayCustomer>
Create a new customer.
delete(String customerId) Future<void>
Delete a customer by ID.
get(String customerId) Future<OpenpayCustomer>
Retrieve a customer by ID.
list({int? offset, int? limit, String? externalId}) Future<List<OpenpayCustomer>>
List customers with optional pagination and filtering.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(String customerId, OpenpayCustomer customer) Future<OpenpayCustomer>
Update an existing customer.

Operators

operator ==(Object other) bool
The equality operator.
inherited