OpenpayToken class

Represents a token returned after successful card tokenization.

The id is the token identifier that should be sent to your backend to create a charge. Card data in this object is masked/partial.

Constructors

OpenpayToken({required String id, String? cardId, String? brand, String? holderName, String? expirationMonth, String? expirationYear, String? cardNumberMasked, String? bankName, String? bankCode, bool? allowsCharges, bool? allowPayouts})
const

Properties

allowPayouts bool?
final
allowsCharges bool?
final
bankCode String?
final
bankName String?
final
brand String?
Card brand (e.g. "visa", "mastercard", "american_express").
final
cardId String?
final
cardNumberMasked String?
Masked card number (e.g. "411111XXXXXX1111").
final
expirationMonth String?
final
expirationYear String?
final
hashCode int
The hash code for this object.
no setterinherited
holderName String?
final
id String
The token ID to be used for charges.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited